@@ -273,6 +273,7 @@ calc_size (HTMLObject *self, HTMLPainter *painter, GList **changed_objs)
 {
 	HTMLText *owner;
 	HTMLTextSlave *slave;
+	HTMLObject *next;
 	GtkHTMLFontStyle font_style;
 	gint new_ascent, new_descent, new_width;
 	gboolean changed;
@@ -298,7 +299,11 @@ calc_size (HTMLObject *self, HTMLPainter *painter, GList **changed_objs)
 	}
 
 	new_width = MAX (1, calc_width (slave, painter));
-	if ((HTML_IS_PLAIN_PAINTER (painter) || HTML_IS_GDK_PAINTER (painter))
+
+	next = HTML_OBJECT (slave)->next;
+	if ((slave->start_word == owner->words - 1
+	     && (!next || (HTML_IS_TEXT_SLAVE (next) && HTML_TEXT_SLAVE (next)->start_word == slave->start_word + 1)))
+	    && (HTML_IS_PLAIN_PAINTER (painter) || HTML_IS_GDK_PAINTER (painter))
 	    && new_width > HTML_OBJECT (owner)->max_width)
 		slave_split_if_too_long (slave, painter, &new_width);
 
@@ -779,15 +784,16 @@ get_offset_for_pointer (HTMLTextSlave *slave, HTMLPainter *painter, gint x, gint
 
 	i = 1;
 	word = 1;
-	space = strchr (owner->text + slave->posStart, ' ');
-	if (space && space - owner->text - slave->posStart <= slave->posLen) {
+	text = html_text_slave_get_text (slave);
+	space = strchr (text, ' ');
+	if (space && g_utf8_pointer_to_offset (text, space) <= slave->posLen) {
 		html_text_request_word_width (owner, painter);
 
 		ww = get_words_width (owner, painter, slave->start_word, word);
-		while (ww < x) {
-			i = space - owner->text - slave->posStart;
+		while (ww < x && space) {
+			i = g_utf8_pointer_to_offset (text, space);
 			space = strchr (space + 1, ' ');
-			if (space && space - owner->text - slave->posStart >= slave->posLen) {
+			if (space && g_utf8_pointer_to_offset (text, space) >= slave->posLen) {
 				break;
 			}
 			word ++;
@@ -795,7 +801,6 @@ get_offset_for_pointer (HTMLTextSlave *slave, HTMLPainter *painter, gint x, gint
 		}
 	}
 
-	text = html_text_slave_get_text (slave);
 	for ( ; i <= slave->posLen; i++) {
 		lo = line_offset;
 		width = html_painter_calc_text_width (painter, text, 
@@ -833,7 +838,6 @@ check_point (HTMLObject *self,
 	return NULL;
 }
 
-
 void
 html_text_slave_type_init (void)
 {
